==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/InformalArgumentSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.message.InformalArgument;
import io.ciera.tool.sql.ooaofooa.message.InformalArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.MessageArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.impl.MessageArgumentSetImpl;

import java.util.Arrays;
import java.util.List;


public class InformalArgumentSetImpl extends InstanceSet<InformalArgumentSet,InformalArgument> implements InformalArgumentSet {

    // attributes
    @Override
    public void setArg_ID( UniqueId ref_Arg_ID ) throws XtumlException {
        for ( InformalArgument informalargument : this ) informalargument.setArg_ID( ref_Arg_ID );
    }


    // selections
    @Override
    public MessageArgumentSet R1013_is_a_MessageArgument() throws XtumlException {
        MessageArgumentSet messageargumentset = new MessageArgumentSetImpl();
        for ( InformalArgument informalargument : this ) messageargumentset.add( informalargument.R1013_is_a_MessageArgument() );
        return messageargumentset;
    }


    @Override
    public InformalArgument nullElement() {
        return InformalArgumentImpl.EMPTY_INFORMALARGUMENT;
    }

    @Override
    public InformalArgumentSet emptySet() {
      return new InformalArgumentSetImpl();
    }

    @Override
    public InformalArgumentSet value() {
        return this;
    }

    @Override
    public List<InformalArgument> elements() {
        return Arrays.asList(toArray(new InformalArgument[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/InformalArgumentSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.message.InformalArgument;
import io.ciera.tool.sql.ooaofooa.message.InformalArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.MessageArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.impl.MessageArgumentSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class InformalArgumentSetImpl extends InstanceSet<InformalArgumentSet,InformalArgument> implements InformalArgumentSet {

    public InformalArgumentSetImpl() {
    }

    public InformalArgumentSetImpl(Comparator<? super InformalArgument> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setArg_ID( UniqueId ref_Arg_ID ) throws XtumlException {
        for ( InformalArgument informalargument : this ) informalargument.setArg_ID( ref_Arg_ID );
    }


    // selections
    @Override
    public MessageArgumentSet R1013_is_a_MessageArgument() throws XtumlException {
        MessageArgumentSet messageargumentset = new MessageArgumentSetImpl();
        for ( InformalArgument informalargument : this ) messageargumentset.add( informalargument.R1013_is_a_MessageArgument() );
        return messageargumentset;
    }


    @Override
    public InformalArgument nullElement() {
        return InformalArgumentImpl.EMPTY_INFORMALARGUMENT;
    }

    @Override
    public InformalArgumentSet emptySet() {
      return new InformalArgumentSetImpl();
    }

    @Override
    public InformalArgumentSet emptySet(Comparator<? super InformalArgument> comp) {
      return new InformalArgumentSetImpl(comp);
    }

    @Override
    public InformalArgumentSet value() {
        return this;
    }

    @Override
    public List<InformalArgument> elements() {
        return Arrays.asList(toArray(new InformalArgument[0]));
    }

}
